PTQTE.Khmaladze.fit: Quantile-Based Permutation Test with an Estimated Nuisance Parameter
Description
A permutation test for testing whether the quantile treatment effects are constant across quantiles. The permutation test considered here is based on the Khmaladze transformation of the quantile process (Koenler and Xiao (2002)), and adapted by Chung and Olivares (2021).
Usage
PTQTE.Khmaladze.fit(
Y,
Z,
taus = seq(0.1, 0.9, by = 0.05),
alpha = 0.05,
n.perm = 999
)
Value
An object of class "PTQTE.Khmaladze" containing at least the following components:
n_populations
Number of grups.
N
Sample Size.
KS.obs
Observed two-sample Kolmogorov-Smirnov test statistic based on the quantile process.
shift
The estimated nuisance parameter.
rej.rule
Binary decision for the permutation test, where 1 means rejection.
pvalue
P-value.
KS.perm
Vector. Test statistic recalculated for all permutations used in the stochastic approximation.
n_perm
Number of permutations.
sample_sizes
Groups size.
Arguments
Y
Numeric. Vector of responses.
Z
Numeric. Treatment indicator. Z=1 if the unit is in the treatment group, and Z=0 if the unit is in the control group.
taus
quantiles at which the process is to be evaluated, if any of the taus lie outside (0,1) then the full process is computed for all distinct solutions.
alpha
Significance level.
n.perm
Numeric. Number of permutations needed for the stochastic approximation of the p-values. The default is n.perm=999.
Author
Maurcio Olivares
References
Khmaladze, E. (1981). Martingale Approach in the Theory of Goodness-of-fit Tests. Theory of Probability and its Application, 26: 240–257.
Koenker, R. and Xiao, Z. (2002) Inference on the Quantile Regression Process. Econometrica, 70(4): 1583-1612.
Chung, E. and Olivares, M. (2021). Comment on "Can Variation in Subgroups' Average Treatment Effects Explain Treatment Effect Heterogeneity? Evidence from a Social Experiment."