summary method for class "PT.Khmaladze.fit"
# S3 method for PT.Khmaladze.MultTest
summary(object, ..., digits = max(3, getOption("digits") - 3))summary.PT.Khmaladze.MultTest returns an object of class "summary.PT.Khmaladze.MultTest" which has the following components
Matrix with the Testing Problem, Number of Permutations for the test and the multiple testing procedure, number of subgroups, (raw) p-values, adjusted p-values, Test Statistic.
an object of class "PT.Khmaladze.MultTest", usually a result of a call to PT.Khmaladze.MultTest
unused
number of digits to display
Maurcio Olivares