summary method for class "PTQTE.Khmaladze.fit"
# S3 method for PTQTE.Khmaladze.fit
summary(object, ..., digits = max(3, getOption("digits") - 3))PTQTE.Khmaladze.fit returns an object of class "PTQTE.Khmaladze.fit" which has the following components
Matrix with the Testing Problem, Sample Sizes, Number of Permutations, Observed test Statistic, Binary Rule and Significance Level.
an object of class "PTQTE.Khmaladze.fit", the result of calling PTQTE.Khmaladze.fit
unused
number of digits to display
Maurcio Olivares